@@ -2,11 +2,11 @@ use crate::software_vault::{SoftwareVault, VaultEntry};
 use crate::VaultError;
 use arrayref::array_ref;
 use core::convert::TryInto;
+use ockam_core::compat::rand::{thread_rng, RngCore};
 use ockam_vault_core::{
     KeyId, KeyIdVault, PublicKey, Secret, SecretAttributes, SecretKey, SecretPersistence,
     SecretType, SecretVault, AES128_SECRET_LENGTH, AES256_SECRET_LENGTH, CURVE25519_SECRET_LENGTH,
 };
-use rand::{thread_rng, RngCore};
 use signature_bbs_plus::PublicKey as BlsPublicKey;
 use signature_bbs_plus::SecretKey as BlsSecretKey;
 use zeroize::Zeroize;
